Contains utility functions useful for neovim/vim operations
Functions
- find_
cmd - Checks for neovim and vim on path, returning a
Cmdfor one of them if found, or anio::Errorif neither is available - has_
nvim_ on_ path - Returns true if able to spawn an nvim process
- has_
vim_ on_ path - Returns true if able to spawn a vim process